@@ -17,22 +17,22 @@ var searchData=
   ['acidtempo_14',['acidTempo',['../classWavAudioFormat.html#ac534d5f34f226b43dd6c03387f9aa9a5',1,'WavAudioFormat']]],
   ['action_15',['action',['../structPopupMenu_1_1Item.html#ac33ad5e4444e9215c8b4ab3a76a0243d',1,'PopupMenu::Item']]],
   ['actions_16',['actions',['../structPushNotifications_1_1Notification.html#a0a9804791528133bf6a31f293300e29e',1,'PushNotifications::Notification::actions'],['../structPushNotifications_1_1Settings_1_1Category.html#a9d683623a02780751a4ade7f0db55220',1,'PushNotifications::Settings::Category::actions']]],
-  ['active_17',['active',['../classIIRFilterBase.html#ad8b40797aa55fe60ac888e334a20ada1',1,'IIRFilterBase']]],
+  ['active_17',['active',['../classIIRFilterBase.html#ad8b40797aa55fe60ac888e334a20ada1',1,'IIRFilterBase::active'],['../structjuce_1_1midi__ci_1_1SupportedAndActive.html#a719e9af3f10793338b7116261f528eac',1,'juce::midi_ci::SupportedAndActive::active']]],
   ['adddefaultheader_18',['addDefaultHeader',['../structXmlElement_1_1TextFormat.html#a6c3d0ac316e68e5afab517c54b75386f',1,'XmlElement::TextFormat']]],
-  ['address_19',['address',['../classIPAddress.html#a2be5eab7b1b7d2e39d8d5367642f3004',1,'IPAddress::address'],['../structNetworkServiceDiscovery_1_1Service.html#ade832707345fb61ef8ed0332ef995ee9',1,'NetworkServiceDiscovery::Service::address']]],
+  ['address_19',['address',['../classIPAddress.html#a2be5eab7b1b7d2e39d8d5367642f3004',1,'IPAddress::address'],['../structNetworkServiceDiscovery_1_1Service.html#ade832707345fb61ef8ed0332ef995ee9',1,'NetworkServiceDiscovery::Service::address'],['../classjuce_1_1midi__ci_1_1ProfileAtAddress.html#a661a640730a8295417ae5a2b6ff3d2ab',1,'juce::midi_ci::ProfileAtAddress::address']]],
   ['alertonlyonce_20',['alertOnlyOnce',['../structPushNotifications_1_1Notification.html#ab134a2585ba8b5064397ed3c56202af0',1,'PushNotifications::Notification']]],
-  ['aliceblue_21',['aliceblue',['../namespaceColours.html#a54fefe6d70a212baebc2eda2c854abba',1,'Colours']]],
+  ['aliceblue_21',['aliceblue',['../namespacejuce_1_1Colours.html#a8b5011b0c40b82f37eba4817bf7c21d3',1,'juce::Colours']]],
   ['aligncontent_22',['alignContent',['../classFlexBox.html#a8e1ae8a873d7ff198f439d3088192bcf',1,'FlexBox::alignContent'],['../classGrid.html#a315d33b518dd1dc90068a51822b030ac',1,'Grid::alignContent']]],
   ['alignitems_23',['alignItems',['../classFlexBox.html#a9e928c10773d54e50e4bfcfc2814f541',1,'FlexBox::alignItems'],['../classGrid.html#a1ea337d65d875793edcfd4b195040f39',1,'Grid::alignItems']]],
-  ['alignself_24',['alignSelf',['../classGridItem.html#a8c48a9ecf979e0b9493e12ecc629a916',1,'GridItem::alignSelf'],['../classFlexItem.html#a7b9190e838f5ee0d70d1cac494621fd7',1,'FlexItem::alignSelf']]],
+  ['alignself_24',['alignSelf',['../classFlexItem.html#a7b9190e838f5ee0d70d1cac494621fd7',1,'FlexItem::alignSelf'],['../classGridItem.html#a8c48a9ecf979e0b9493e12ecc629a916',1,'GridItem::alignSelf']]],
   ['allowalert_25',['allowAlert',['../structPushNotifications_1_1Settings.html#adb0e3b50f514b8179823c55b4c5ee295',1,'PushNotifications::Settings']]],
   ['allowbadge_26',['allowBadge',['../structPushNotifications_1_1Settings.html#a36b3ffa30490b4a45cc7817186f29a14',1,'PushNotifications::Settings']]],
   ['allowedresponses_27',['allowedResponses',['../structPushNotifications_1_1Notification_1_1Action.html#a3d60731f473175aa7dbe1b853227ed8b',1,'PushNotifications::Notification::Action']]],
   ['allowsound_28',['allowSound',['../structPushNotifications_1_1Settings.html#ab9d707cf7dc2476213ac57ecb6a0cd4d',1,'PushNotifications::Settings']]],
-  ['alpha_29',['alpha',['../structdsp_1_1FilterDesign_1_1IIRPolyphaseAllpassStructure.html#aa5dfc4c01cbec7c87be7b263f9c399be',1,'dsp::FilterDesign::IIRPolyphaseAllpassStructure::alpha'],['../structOSCColour.html#a09b39b90c61259a30ca891063bc9bfbc',1,'OSCColour::alpha']]],
+  ['alpha_29',['alpha',['../structjuce_1_1dsp_1_1FilterDesign_1_1IIRPolyphaseAllpassStructure.html#a13f39abf4cea20e1413f07cb533d81b7',1,'juce::dsp::FilterDesign::IIRPolyphaseAllpassStructure::alpha'],['../structOSCColour.html#a09b39b90c61259a30ca891063bc9bfbc',1,'OSCColour::alpha']]],
   ['alphabits_30',['alphaBits',['../classOpenGLPixelFormat.html#a4d947e7a9831d9158f2a0b519d7d3497',1,'OpenGLPixelFormat']]],
   ['anchor_31',['anchor',['../classTextLayout_1_1Glyph.html#a5ed7fd244c70a76748ced04c222cfb87',1,'TextLayout::Glyph']]],
-  ['antiquewhite_32',['antiquewhite',['../namespaceColours.html#a90f69553443fe6747b11bc1f648b976c',1,'Colours']]],
+  ['antiquewhite_32',['antiquewhite',['../namespacejuce_1_1Colours.html#a6931a1cc2f0b80835d52e9933b668355',1,'juce::Colours']]],
   ['applebeats_33',['appleBeats',['../classAiffAudioFormat.html#a6bb37fe682296874d508bead17cca803',1,'AiffAudioFormat']]],
   ['appledenominator_34',['appleDenominator',['../classAiffAudioFormat.html#afd67205870de9ed8615b6dbaf688ab7a',1,'AiffAudioFormat']]],
   ['applekey_35',['appleKey',['../classAiffAudioFormat.html#a0cc420a19cd83e233cc9a1318c081659',1,'AiffAudioFormat']]],
@@ -43,15 +43,15 @@ var searchData=
   ['appletag_40',['appleTag',['../classAiffAudioFormat.html#ae70d490b15000091780a97d9b1913f32',1,'AiffAudioFormat']]],
   ['applicationbundlename_41',['applicationBundleName',['../structInAppPurchases_1_1Purchase.html#a5950a9e263d0834b3f42851bcfa23c48',1,'InAppPurchases::Purchase']]],
   ['applicationname_42',['applicationName',['../structPropertiesFile_1_1Options.html#a6222c4cfec8124ae0af33398a61f2517',1,'PropertiesFile::Options']]],
-  ['aqua_43',['aqua',['../namespaceColours.html#a8fa64c7acebb2a4c5a28b927f673b3d8',1,'Colours']]],
-  ['aquamarine_44',['aquamarine',['../namespaceColours.html#ae57648e6a23a907a18d6620ea05d941c',1,'Colours']]],
+  ['aqua_43',['aqua',['../namespacejuce_1_1Colours.html#a921358f30c73f8cce901335631aabe71',1,'juce::Colours']]],
+  ['aquamarine_44',['aquamarine',['../namespacejuce_1_1Colours.html#a6e054749b7b449cb668ee10693fb2c56',1,'juce::Colours']]],
   ['aradocumentcontroller_45',['ARADocumentController',['../classARAAudioSource.html#a843d873832aa7c76bfc442a58e466ae8',1,'ARAAudioSource']]],
   ['arafactory_46',['araFactory',['../structARAFactoryResult.html#a4a6e086542f278f6441fee94a8e616a2',1,'ARAFactoryResult']]],
   ['area_47',['area',['../classGridItem.html#aa1d3cb3665477cdb7b58a607b779f8f3',1,'GridItem']]],
   ['argumentdescription_48',['argumentDescription',['../structConsoleApplication_1_1Command.html#a58d4d1dcda368f079ea7f648e89349a2',1,'ConsoleApplication::Command']]],
   ['arguments_49',['arguments',['../structvar_1_1NativeFunctionArgs.html#a6c898b57ab92fb3084a78a4713ae2065',1,'var::NativeFunctionArgs::arguments'],['../structArgumentList.html#aebbb44f0cabf89cc672536887be82915',1,'ArgumentList::arguments']]],
   ['ascent_50',['ascent',['../classCustomTypeface.html#ab5c74224ec102b6990481b658d189ac4',1,'CustomTypeface::ascent'],['../classTextLayout_1_1Line.html#ac356b4c8bd159161ac80438457471d7d',1,'TextLayout::Line::ascent']]],
-  ['associatedcomponent_51',['associatedComponent',['../classGridItem.html#a5c2e9d897bcb5530d598aff2f910371a',1,'GridItem::associatedComponent'],['../classFlexItem.html#a844775f34c346b8e807c66d3623d9ea8',1,'FlexItem::associatedComponent']]],
+  ['associatedcomponent_51',['associatedComponent',['../classFlexItem.html#a844775f34c346b8e807c66d3623d9ea8',1,'FlexItem::associatedComponent'],['../classGridItem.html#a5c2e9d897bcb5530d598aff2f910371a',1,'GridItem::associatedComponent']]],
   ['associatedflexbox_52',['associatedFlexBox',['../classFlexItem.html#ae91dba1ed2ad5a26f0b2733060dbd5ac',1,'FlexItem']]],
   ['aswgaccent_53',['aswgAccent',['../classWavAudioFormat.html#adef504fcd90bd4f2fe8dd162c8b44090',1,'WavAudioFormat']]],
   ['aswgactorgender_54',['aswgActorGender',['../classWavAudioFormat.html#a1dcebe466a57971170eab681cb529f6a',1,'WavAudioFormat']]],
@@ -145,5 +145,5 @@ var searchData=
   ['autorows_142',['autoRows',['../classGrid.html#a79c7bfbb5bab511a2b950f8f4d33ba5c',1,'Grid']]],
   ['autovalue_143',['autoValue',['../classFlexItem.html#af32603bdf7f814f6d73a999b54a34df6',1,'FlexItem']]],
   ['averageseconds_144',['averageSeconds',['../structPerformanceCounter_1_1Statistics.html#a1ddbe61fd1a766973cc19d9c3432a4c6',1,'PerformanceCounter::Statistics']]],
-  ['azure_145',['azure',['../namespaceColours.html#a4b18a514ccb0035c2e6af6ee7c2079f7',1,'Colours']]]
+  ['azure_145',['azure',['../namespacejuce_1_1Colours.html#a85c402f820d926db8e54e7a24ca897e3',1,'juce::Colours']]]
 ];
